<?php
session_start();

define('DB_HOST', 'localhost'); //数据库主机地址
define('DB_NAME', 'cafeease'); //数据库名称
define('DB_USER', 'root'); //数据库用户名
define('DB_PASS', 'root'); //数据库密码
define('title', 'CA398-咖易管（CafeEase）'); //系统名称
define('subtitle', '咖啡店连锁门店管理系统'); //系统副标题

try {
    $pdo = new PDO(
        "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME . ";charset=utf8mb4",
        DB_USER,
        DB_PASS,
        [
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC
        ]
    );
} catch (PDOException $e) {
    die("数据库连接失败: " . $e->getMessage());
}

// 以下内容需要按照实际数据库表的结构进行修改
/**
 * 记录操作日志

 * @param string $operation 操作描述
 * @return bool 是否记录成功
 */
function record_log($operation)
{
    global $pdo;

    $user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
    $username = isset($_SESSION['username']) ? $_SESSION['username'] : null;
    $ip = get_client_ip(); // 使用已有的获取IP地址函数

    try {
        $stmt = $pdo->prepare("INSERT INTO sys_logs (user_id, username, operation, ip) VALUES (?, ?, ?, ?)");
        return $stmt->execute([$user_id, $username, $operation, $ip]);
    } catch (PDOException $e) {
        // 日志记录失败，但不影响主程序运行
        error_log("记录日志失败: " . $e->getMessage());
        return false;
    }
}

/**
 * 获取客户端IP地址
 * @return string 客户端IP地址
 */
function get_client_ip()
{
    if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
        $ip = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
    } else {
        $ip = $_SERVER['REMOTE_ADDR'];
    }
    return $ip;
}

/**
 * 检查当前用户是否有指定权限
 * @param string $permission_code 权限编码
 * @return bool 是否有权限
 */
function has_permission($permission_code)
{
    // 未登录用户没有任何权限
    if (!isset($_SESSION['user_id']) || !isset($_SESSION['role_id'])) {
        return false;
    }

    // 获取用户角色权限
    $permissions = get_role_permissions($_SESSION['role_id']);

    // 系统管理员或具有all权限的用户拥有所有权限
    if ($permissions && (isset($permissions['all']) || $_SESSION['role_id'] == 1)) {
        return true;
    }

    // 检查具体权限
    // 处理嵌套权限，如 system.user 格式
    if (strpos($permission_code, '.') !== false) {
        list($module, $action) = explode('.', $permission_code);

        // 检查是否有整个模块的权限
        if (isset($permissions[$module]) && $permissions[$module] === true) {
            return true;
        }

        // 检查是否有特定操作的权限
        if (isset($permissions[$module]) && is_array($permissions[$module]) && isset($permissions[$module][$action])) {
            return true;
        }
    } else {
        // 简单权限检查
        if (isset($permissions[$permission_code]) && $permissions[$permission_code] === true) {
            return true;
        }
    }

    return false;
}

/**
 * 获取角色权限
 * @param int $role_id 角色ID
 * @return array 权限数组
 */
function get_role_permissions($role_id)
{
    global $pdo;

    try {
        $stmt = $pdo->prepare("SELECT permissions FROM sys_roles WHERE id = ?");
        $stmt->execute([$role_id]);
        $result = $stmt->fetch();

        if ($result && !empty($result['permissions'])) {
            return json_decode($result['permissions'], true);
        }

        return [];
    } catch (PDOException $e) {
        error_log("获取角色权限失败: " . $e->getMessage());
        return [];
    }
}

/**
 * 检查当前用户是否有权限，如无权限则跳转到无权限页面
 * @param string $permission_code 权限编码
 */
function check_permission_or_die($permission_code)
{
    if (!has_permission($permission_code)) {
        // 记录未授权访问日志
        record_log("未授权访问: " . $permission_code);

        // 跳转到无权限页面
        // 这里无需修改
        header("Location: error.php?code=403");
        exit;
    }
}
