<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('inventory.supplier');

// 记录访问日志
record_log('访问供应商管理页面');

// 添加/编辑供应商处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加供应商
    if ($_POST['action'] == 'add') {
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $contact = isset($_POST['contact']) ? trim($_POST['contact']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $category = isset($_POST['category']) ? trim($_POST['category']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($name)) {
            $error = '请填写供应商名称！';
        } else {
            try {
                // 检查供应商名称是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sup_info WHERE name = ?");
                $stmt->execute([$name]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '供应商名称已存在！';
                } else {
                    // 添加供应商
                    $stmt = $pdo->prepare("INSERT INTO sup_info (name, contact, phone, address, category, status) VALUES (?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$name, $contact, $phone, $address, $category, $status]);

                    if ($result) {
                        record_log("添加供应商：{$name}");
                        $success = '供应商添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: supplier.php?success=add');
                        exit;
                    } else {
                        $error = '供应商添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑供应商
    elseif ($_POST['action'] == 'edit') {
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $contact = isset($_POST['contact']) ? trim($_POST['contact']) : '';
        $phone = isset($_POST['phone']) ? trim($_POST['phone']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $category = isset($_POST['category']) ? trim($_POST['category']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($supplier_id <= 0 || empty($name)) {
            $error = '请填写完整供应商信息！';
        } else {
            try {
                // 检查供应商名称是否已被其他供应商使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sup_info WHERE name = ? AND id != ?");
                $stmt->execute([$name, $supplier_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '供应商名称已被使用！';
                } else {
                    // 更新供应商信息
                    $stmt = $pdo->prepare("UPDATE sup_info SET name = ?, contact = ?, phone = ?, address = ?, category = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$name, $contact, $phone, $address, $category, $status, $supplier_id]);

                    if ($result) {
                        record_log("编辑供应商：{$name}");
                        $success = '供应商信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: supplier.php?success=edit');
                        exit;
                    } else {
                        $error = '供应商信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除供应商
    elseif ($_POST['action'] == 'delete') {
        $supplier_id = isset($_POST['supplier_id']) ? intval($_POST['supplier_id']) : 0;

        if ($supplier_id <= 0) {
            $error = '无效的供应商ID！';
        } else {
            try {
                // 获取供应商名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM sup_info WHERE id = ?");
                $stmt->execute([$supplier_id]);
                $supplier = $stmt->fetch();

                if (!$supplier) {
                    $error = '供应商不存在！';
                } else {
                    // 检查供应商是否有关联采购订单
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM pur_order WHERE supplier_id = ?");
                    $stmt->execute([$supplier_id]);
                    $order_count = $stmt->fetch();

                    if ($order_count['count'] > 0) {
                        $error = '该供应商存在采购订单记录，无法删除！';
                    } else {
                        // 删除供应商
                        $stmt = $pdo->prepare("DELETE FROM sup_info WHERE id = ?");
                        $result = $stmt->execute([$supplier_id]);

                        if ($result) {
                            record_log("删除供应商：{$supplier['name']}");
                            $success = '供应商删除成功！';
                        } else {
                            $error = '供应商删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有供应商
try {
    $stmt = $pdo->query("SELECT * FROM sup_info ORDER BY id DESC");
    $suppliers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取供应商列表失败：' . $e->getMessage();
    $suppliers = [];
}

// 判断是否显示表单
$show_form = false;
$edit_supplier = null;

// 编辑供应商时显示表单并获取供应商信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM sup_info WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_supplier = $stmt->fetch();
        if (!$edit_supplier) {
            $error = '供应商不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取供应商信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加供应商时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '供应商添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '供应商信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>供应商管理</h2>
            <div class="breadcrumb">
                <a href="index.php">库存管理</a> &gt; 供应商管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="supplier.php?action=add" class="btn btn-add">添加供应商</a>
            </div>

            <!-- 添加/编辑供应商表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_supplier ? '编辑供应商' : '添加供应商'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_supplier ? 'edit' : 'add'; ?>">
                        <?php if ($edit_supplier): ?>
                            <input type="hidden" name="supplier_id" value="<?php echo $edit_supplier['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="name">供应商名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_supplier ? htmlspecialchars($edit_supplier['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="contact">联系人：</label>
                            <input type="text" id="contact" name="contact" value="<?php echo $edit_supplier ? htmlspecialchars($edit_supplier['contact']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="phone">联系电话：</label>
                            <input type="text" id="phone" name="phone" value="<?php echo $edit_supplier ? htmlspecialchars($edit_supplier['phone']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="address">地址：</label>
                            <input type="text" id="address" name="address" value="<?php echo $edit_supplier ? htmlspecialchars($edit_supplier['address']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="category">供应类别：</label>
                            <input type="text" id="category" name="category" value="<?php echo $edit_supplier ? htmlspecialchars($edit_supplier['category']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_supplier && $edit_supplier['status'] == 1) ? 'selected' : ''; ?>>正常</option>
                                <option value="0" <?php echo ($edit_supplier && $edit_supplier['status'] == 0) ? 'selected' : ''; ?>>停用</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="supplier.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 供应商列表 -->
            <div class="table-container">
                <h3>供应商列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>供应商名称</th>
                            <th>联系人</th>
                            <th>联系电话</th>
                            <th>地址</th>
                            <th>供应类别</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($suppliers)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无供应商数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($suppliers as $supplier): ?>
                                <tr>
                                    <td><?php echo $supplier['id']; ?></td>
                                    <td><?php echo htmlspecialchars($supplier['name']); ?></td>
                                    <td><?php echo htmlspecialchars($supplier['contact'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($supplier['phone'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($supplier['address'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($supplier['category'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($supplier['status'] == 1) echo '<span class="status-active">正常</span>';
                                        else echo '<span class="status-inactive">停用</span>';
                                        ?>
                                    </td>
                                    <td>
                                        <a href="supplier.php?action=edit&id=<?php echo $supplier['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="supplier_id" value="<?php echo $supplier['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除供应商 \'<?php echo htmlspecialchars($supplier['name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>