<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('member.card');

// 记录访问日志
record_log('访问会员储值管理页面');

// 初始化变量
$view_card_rules = false;
$card_rules = [];
$view_card_records = false;
$card_records = [];

// 处理储值规则添加/编辑
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加储值规则
    if ($_POST['action'] == 'add_rule') {
        $rule_name = isset($_POST['rule_name']) ? trim($_POST['rule_name']) : '';
        $charge_amount = isset($_POST['charge_amount']) ? floatval($_POST['charge_amount']) : 0;
        $bonus_amount = isset($_POST['bonus_amount']) ? floatval($_POST['bonus_amount']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';

        if (empty($rule_name) || $charge_amount <= 0) {
            $error = '请填写完整规则信息！';
        } else {
            try {
                // 添加储值规则
                $stmt = $pdo->prepare("INSERT INTO mkt_charge_rule (rule_name, charge_amount, bonus_amount, status, description, create_time) VALUES (?, ?, ?, ?, ?, NOW())");
                $result = $stmt->execute([$rule_name, $charge_amount, $bonus_amount, $status, $description]);

                if ($result) {
                    record_log("添加储值规则：{$rule_name}");
                    $success = '储值规则添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: card.php?success=add_rule');
                    exit;
                } else {
                    $error = '储值规则添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑储值规则
    elseif ($_POST['action'] == 'edit_rule') {
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;
        $rule_name = isset($_POST['rule_name']) ? trim($_POST['rule_name']) : '';
        $charge_amount = isset($_POST['charge_amount']) ? floatval($_POST['charge_amount']) : 0;
        $bonus_amount = isset($_POST['bonus_amount']) ? floatval($_POST['bonus_amount']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';

        if ($rule_id <= 0 || empty($rule_name) || $charge_amount <= 0) {
            $error = '请填写完整规则信息！';
        } else {
            try {
                // 更新储值规则
                $stmt = $pdo->prepare("UPDATE mkt_charge_rule SET rule_name = ?, charge_amount = ?, bonus_amount = ?, status = ?, description = ? WHERE id = ?");
                $result = $stmt->execute([$rule_name, $charge_amount, $bonus_amount, $status, $description, $rule_id]);

                if ($result) {
                    record_log("编辑储值规则：{$rule_name}");
                    $success = '储值规则更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: card.php?success=edit_rule');
                    exit;
                } else {
                    $error = '储值规则更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除储值规则
    elseif ($_POST['action'] == 'delete_rule') {
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;

        if ($rule_id <= 0) {
            $error = '无效的规则ID！';
        } else {
            try {
                // 获取规则名称，用于日志记录
                $stmt = $pdo->prepare("SELECT rule_name FROM mkt_charge_rule WHERE id = ?");
                $stmt->execute([$rule_id]);
                $rule = $stmt->fetch();

                if (!$rule) {
                    $error = '规则不存在！';
                } else {
                    // 删除规则
                    $stmt = $pdo->prepare("DELETE FROM mkt_charge_rule WHERE id = ?");
                    $result = $stmt->execute([$rule_id]);

                    if ($result) {
                        record_log("删除储值规则：{$rule['rule_name']}");
                        $success = '储值规则删除成功！';
                    } else {
                        $error = '储值规则删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 会员充值
    elseif ($_POST['action'] == 'charge_account') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $payment_type = isset($_POST['payment_type']) ? intval($_POST['payment_type']) : 1;
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($member_id <= 0 || $amount <= 0) {
            $error = '请选择会员并输入充值金额！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 获取会员信息
                $stmt = $pdo->prepare("SELECT * FROM mem_info WHERE id = ?");
                $stmt->execute([$member_id]);
                $member = $stmt->fetch();

                if (!$member) {
                    throw new Exception('会员不存在！');
                }

                // 计算赠送金额
                $bonus_amount = 0;
                if ($rule_id > 0) {
                    // 获取规则信息
                    $stmt = $pdo->prepare("SELECT * FROM mkt_charge_rule WHERE id = ? AND status = 1");
                    $stmt->execute([$rule_id]);
                    $rule = $stmt->fetch();

                    if ($rule && $amount >= $rule['charge_amount']) {
                        // 计算赠送金额（可能会有多个赠送）
                        $bonus_count = floor($amount / $rule['charge_amount']);
                        $bonus_amount = $bonus_count * $rule['bonus_amount'];

                        // 更新备注
                        if (empty($remark)) {
                            $remark = "充值优惠：" . $rule['rule_name'];
                        } else {
                            $remark .= " | 充值优惠：" . $rule['rule_name'];
                        }
                    }
                }

                // 总金额（充值金额 + 赠送金额）
                $total_amount = $amount + $bonus_amount;

                // 添加充值记录
                $payment_text = ['', '现金', '微信', '支付宝', '银行卡'][$payment_type];
                $charge_remark = "充值：¥" . number_format($amount, 2) . "（{$payment_text}）";
                if ($bonus_amount > 0) {
                    $charge_remark .= " + 赠送：¥" . number_format($bonus_amount, 2);
                }
                if (!empty($remark)) {
                    $charge_remark .= " | " . $remark;
                }

                $stmt = $pdo->prepare("INSERT INTO mem_record (member_id, type, amount, remark, create_time) VALUES (?, 3, ?, ?, NOW())");
                $result = $stmt->execute([$member_id, $total_amount, $charge_remark]);

                if ($result) {
                    // 更新会员余额
                    $stmt = $pdo->prepare("UPDATE mem_info SET balance = balance + ? WHERE id = ?");
                    $stmt->execute([$total_amount, $member_id]);

                    // 提交事务
                    $pdo->commit();

                    record_log("会员账户充值：会员ID={$member_id}, 充值金额={$amount}, 赠送金额={$bonus_amount}");
                    $success = '账户充值成功！';

                    // 重定向到没有参数的页面
                    header('Location: card.php?success=charge');
                    exit;
                } else {
                    throw new Exception('账户充值失败！');
                }
            } catch (Exception $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = $e->getMessage();
            }
        }
    }
}

// 显示储值规则设置页面
if (isset($_GET['view']) && $_GET['view'] == 'rules') {
    $view_card_rules = true;

    // 获取所有储值规则
    try {
        // 如果表不存在，则创建表
        $pdo->exec("
            CREATE TABLE IF NOT EXISTS `mkt_charge_rule` (
              `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '规则ID',
              `rule_name` varchar(100) NOT NULL COMMENT '规则名称',
              `charge_amount` decimal(10,2) NOT NULL COMMENT '充值金额',
              `bonus_amount` decimal(10,2) NOT NULL DEFAULT 0 COMMENT '赠送金额',
              `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=启用，0=禁用',
              `description` varchar(255) DEFAULT NULL COMMENT '规则描述',
              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              PRIMARY KEY (`id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='储值规则表';
        ");

        $stmt = $pdo->query("SELECT * FROM mkt_charge_rule ORDER BY charge_amount ASC");
        $card_rules = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取储值规则失败：' . $e->getMessage();
        $card_rules = [];
    }

    // 判断是否显示编辑表单
    $show_rule_form = false;
    $edit_rule = null;

    if (isset($_GET['action']) && $_GET['action'] == 'edit_rule' && isset($_GET['id'])) {
        $show_rule_form = true;
        $edit_id = intval($_GET['id']);
        try {
            $stmt = $pdo->prepare("SELECT * FROM mkt_charge_rule WHERE id = ?");
            $stmt->execute([$edit_id]);
            $edit_rule = $stmt->fetch();
            if (!$edit_rule) {
                $error = '储值规则不存在！';
                $show_rule_form = false;
            }
        } catch (PDOException $e) {
            $error = '获取储值规则失败：' . $e->getMessage();
            $show_rule_form = false;
        }
    }

    // 添加储值规则时显示表单
    if (isset($_GET['action']) && $_GET['action'] == 'add_rule') {
        $show_rule_form = true;
    }
}

// 显示充值记录页面
elseif (isset($_GET['view']) && $_GET['view'] == 'records') {
    $view_card_records = true;

    // 设置筛选条件
    $filter_member_id = isset($_GET['member_id']) ? intval($_GET['member_id']) : 0;
    $filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
    $filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

    // 构建WHERE子句
    $where = [];
    $params = [];

    $where[] = "r.type = 3"; // 只查询充值类型的记录

    if ($filter_member_id > 0) {
        $where[] = "r.member_id = ?";
        $params[] = $filter_member_id;
    }

    if (!empty($filter_start_date)) {
        $where[] = "DATE(r.create_time) >= ?";
        $params[] = $filter_start_date;
    }

    if (!empty($filter_end_date)) {
        $where[] = "DATE(r.create_time) <= ?";
        $params[] = $filter_end_date;
    }

    $where_clause = !empty($where) ? " WHERE " . implode(" AND ", $where) : "";

    // 获取充值记录
    try {
        $sql = "
            SELECT r.*, m.member_no, m.name as member_name, m.phone
            FROM mem_record r
            JOIN mem_info m ON r.member_id = m.id
            $where_clause
            ORDER BY r.create_time DESC
            LIMIT 200
        ";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $card_records = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取充值记录失败：' . $e->getMessage();
        $card_records = [];
    }

    // 获取所有会员（用于筛选）
    try {
        $stmt = $pdo->query("SELECT id, member_no, name, phone FROM mem_info ORDER BY id DESC");
        $members = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取会员列表失败：' . $e->getMessage();
        $members = [];
    }
}
// 默认显示充值页面
else {
    // 获取所有会员
    try {
        $stmt = $pdo->query("SELECT * FROM mem_info WHERE status = 1 ORDER BY id DESC");
        $members = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取会员列表失败：' . $e->getMessage();
        $members = [];
    }

    // 获取所有启用的储值规则
    try {
        // 如果表不存在，则跳过查询
        $table_exists = $pdo->query("SHOW TABLES LIKE 'mkt_charge_rule'")->rowCount() > 0;

        if ($table_exists) {
            $stmt = $pdo->query("SELECT * FROM mkt_charge_rule WHERE status = 1 ORDER BY charge_amount ASC");
            $card_rules = $stmt->fetchAll();
        } else {
            $card_rules = [];
        }
    } catch (PDOException $e) {
        $error = '获取储值规则失败：' . $e->getMessage();
        $card_rules = [];
    }
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add_rule') {
        $success = '储值规则添加成功！';
    } elseif ($_GET['success'] == 'edit_rule') {
        $success = '储值规则更新成功！';
    } elseif ($_GET['success'] == 'charge') {
        $success = '会员账户充值成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员储值管理</h2>
            <div class="breadcrumb">
                <a href="index.php">会员营销</a> &gt; 储值管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="card.php" class="btn <?php echo !$view_card_rules && !$view_card_records ? 'btn-primary' : 'btn-secondary'; ?>">会员充值</a>
                <a href="card.php?view=rules" class="btn <?php echo $view_card_rules ? 'btn-primary' : 'btn-secondary'; ?>">储值规则设置</a>
                <a href="card.php?view=records" class="btn <?php echo $view_card_records ? 'btn-primary' : 'btn-secondary'; ?>">充值记录查询</a>
            </div>

            <?php if ($view_card_rules): ?>
                <!-- 储值规则设置视图 -->
                <div class="action-bar">
                    <a href="card.php?view=rules&action=add_rule" class="btn btn-add">添加储值规则</a>
                </div>

                <?php if ($show_rule_form): ?>
                    <div class="form-container">
                        <h3><?php echo $edit_rule ? '编辑储值规则' : '添加储值规则'; ?></h3>
                        <form method="post" action="">
                            <input type="hidden" name="action" value="<?php echo $edit_rule ? 'edit_rule' : 'add_rule'; ?>">
                            <?php if ($edit_rule): ?>
                                <input type="hidden" name="rule_id" value="<?php echo $edit_rule['id']; ?>">
                            <?php endif; ?>

                            <div class="form-group">
                                <label for="rule_name">规则名称：</label>
                                <input type="text" id="rule_name" name="rule_name" value="<?php echo $edit_rule ? htmlspecialchars($edit_rule['rule_name']) : ''; ?>" required>
                            </div>

                            <div class="form-group">
                                <label for="charge_amount">充值金额：</label>
                                <input type="number" id="charge_amount" name="charge_amount" min="1" step="0.01" value="<?php echo $edit_rule ? number_format($edit_rule['charge_amount'], 2, '.', '') : ''; ?>" required>
                                <small>当会员充值达到该金额时触发优惠</small>
                            </div>

                            <div class="form-group">
                                <label for="bonus_amount">赠送金额：</label>
                                <input type="number" id="bonus_amount" name="bonus_amount" min="0" step="0.01" value="<?php echo $edit_rule ? number_format($edit_rule['bonus_amount'], 2, '.', '') : '0.00'; ?>">
                                <small>例如：充值满500元赠送50元，则赠送金额填写50</small>
                            </div>

                            <div class="form-group">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="1" <?php echo ($edit_rule && $edit_rule['status'] == 1) ? 'selected' : ''; ?>>启用</option>
                                    <option value="0" <?php echo ($edit_rule && $edit_rule['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="description">规则描述：</label>
                                <textarea id="description" name="description" rows="3"><?php echo $edit_rule ? htmlspecialchars($edit_rule['description']) : ''; ?></textarea>
                            </div>

                            <div class="form-actions">
                                <button type="submit" class="btn btn-success">保存</button>
                                <a href="card.php?view=rules" class="btn btn-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                <?php endif; ?>

                <div class="table-container">
                    <h3>储值规则列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>规则名称</th>
                                <th>充值金额</th>
                                <th>赠送金额</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($card_rules)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无储值规则</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($card_rules as $rule): ?>
                                    <tr>
                                        <td><?php echo $rule['id']; ?></td>
                                        <td><?php echo htmlspecialchars($rule['rule_name']); ?></td>
                                        <td><?php echo number_format($rule['charge_amount'], 2); ?> 元</td>
                                        <td><?php echo number_format($rule['bonus_amount'], 2); ?> 元</td>
                                        <td>
                                            <?php
                                            if ($rule['status'] == 1) echo '<span class="status-active">启用</span>';
                                            else echo '<span class="status-inactive">禁用</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($rule['create_time'])); ?></td>
                                        <td>
                                            <a href="card.php?view=rules&action=edit_rule&id=<?php echo $rule['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete_rule">
                                                <input type="hidden" name="rule_id" value="<?php echo $rule['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除规则 \'<?php echo htmlspecialchars($rule['rule_name']); ?>\' 吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php elseif ($view_card_records): ?>
                <!-- 充值记录查询视图 -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <input type="hidden" name="view" value="records">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="member_id">会员：</label>
                                <select id="member_id" name="member_id">
                                    <option value="0">全部</option>
                                    <?php foreach ($members as $member): ?>
                                        <option value="<?php echo $member['id']; ?>" <?php echo ($filter_member_id == $member['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?> (<?php echo htmlspecialchars($member['member_no']); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>

                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="card.php?view=records" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <h3>会员充值记录（最近200条）</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员</th>
                                <th>手机号码</th>
                                <th>充值金额</th>
                                <th>备注</th>
                                <th>充值时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($card_records)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无充值记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($card_records as $record): ?>
                                    <tr>
                                        <td><?php echo $record['id']; ?></td>
                                        <td><?php echo htmlspecialchars($record['member_name'] ?: '-'); ?> (<?php echo htmlspecialchars($record['member_no']); ?>)</td>
                                        <td><?php echo htmlspecialchars($record['phone']); ?></td>
                                        <td><?php echo number_format($record['amount'], 2); ?> 元</td>
                                        <td><?php echo htmlspecialchars($record['remark'] ?: '-'); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($record['create_time'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <!-- 会员充值视图 -->
                <div class="form-container">
                    <h3>会员充值</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="charge_account">

                        <div class="form-group">
                            <label for="member_id">选择会员：</label>
                            <select id="member_id" name="member_id" required>
                                <option value="">请选择会员</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>">
                                        <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?>
                                        (<?php echo htmlspecialchars($member['member_no']); ?>) -
                                        余额: <?php echo number_format($member['balance'], 2); ?> 元
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">充值金额：</label>
                            <input type="number" id="amount" name="amount" min="0.01" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="payment_type">支付方式：</label>
                            <select id="payment_type" name="payment_type">
                                <option value="1">现金</option>
                                <option value="2">微信</option>
                                <option value="3">支付宝</option>
                                <option value="4">银行卡</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="rule_id">优惠规则：</label>
                            <select id="rule_id" name="rule_id">
                                <option value="0">无</option>
                                <?php foreach ($card_rules as $rule): ?>
                                    <option value="<?php echo $rule['id']; ?>">
                                        <?php echo htmlspecialchars($rule['rule_name']); ?> -
                                        充值<?php echo number_format($rule['charge_amount'], 2); ?>元送<?php echo number_format($rule['bonus_amount'], 2); ?>元
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="2"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">确认充值</button>
                            <button type="reset" class="btn btn-secondary">重置</button>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <h3>会员余额列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员编号</th>
                                <th>姓名</th>
                                <th>手机号码</th>
                                <th>会员等级</th>
                                <th>账户余额</th>
                                <th>积分余额</th>
                                <th>累计消费</th>
                                <th>状态</th>
                                <th>注册时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($members)): ?>
                                <tr>
                                    <td colspan="11" class="text-center">暂无会员数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($members as $member): ?>
                                    <tr>
                                        <td><?php echo $member['id']; ?></td>
                                        <td><?php echo htmlspecialchars($member['member_no']); ?></td>
                                        <td><?php echo htmlspecialchars($member['name'] ?: '-'); ?></td>
                                        <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                        <td>
                                            <?php
                                            if ($member['level'] == 1) echo '普通会员';
                                            elseif ($member['level'] == 2) echo '银卡会员';
                                            elseif ($member['level'] == 3) echo '金卡会员';
                                            elseif ($member['level'] == 4) echo '黑卡会员';
                                            ?>
                                        </td>
                                        <td><?php echo number_format($member['balance'], 2); ?> 元</td>
                                        <td><?php echo number_format($member['points']); ?></td>
                                        <td><?php echo number_format($member['total_amount'], 2); ?> 元</td>
                                        <td>
                                            <?php
                                            if ($member['status'] == 1) echo '<span class="status-active">正常</span>';
                                            else echo '<span class="status-inactive">禁用</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($member['create_time'])); ?></td>
                                        <td>
                                            <a href="card.php?view=records&member_id=<?php echo $member['id']; ?>" class="btn btn-sm btn-primary">充值记录</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>