<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('member.notify');

// 记录访问日志
record_log('访问会员通知管理页面');

// 初始化变量
$view_template_list = false;
$view_notify_list = true;
$view_send_notify = false;

// 检查并创建必要的表
try {
    // 检查通知记录表是否存在，不存在则创建
    $table_exists = $pdo->query("SHOW TABLES LIKE 'mkt_notify'")->rowCount() > 0;
    if (!$table_exists) {
        $pdo->exec("
            CREATE TABLE IF NOT EXISTS `mkt_notify` (
              `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '通知ID',
              `template_id` int(11) DEFAULT NULL COMMENT '模板ID',
              `notify_type` tinyint(1) NOT NULL COMMENT '通知类型：1=短信，2=微信',
              `title` varchar(100) DEFAULT NULL COMMENT '通知标题',
              `content` text NOT NULL COMMENT '通知内容',
              `send_type` tinyint(1) NOT NULL COMMENT '发送类型：1=单发，2=批量，3=条件发送',
              `member_ids` text DEFAULT NULL COMMENT '会员ID列表（JSON格式，单发或批量）',
              `condition_type` tinyint(1) DEFAULT NULL COMMENT '条件类型：1=生日，2=消费金额，3=会员等级',
              `condition_value` varchar(255) DEFAULT NULL COMMENT '条件值',
              `total_count` int(11) NOT NULL DEFAULT 0 COMMENT '发送总数',
              `success_count` int(11) NOT NULL DEFAULT 0 COMMENT '成功数量',
              `fail_count` int(11) NOT NULL DEFAULT 0 COMMENT '失败数量',
              `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1=待发送，2=发送中，3=已完成，4=已取消',
              `operator` varchar(50) DEFAULT NULL COMMENT '操作人',
              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `send_time` datetime DEFAULT NULL COMMENT '发送时间',
              PRIMARY KEY (`id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='会员通知记录表';
        ");
    }

    // 检查通知模板表是否存在，不存在则创建
    $table_exists = $pdo->query("SHOW TABLES LIKE 'mkt_notify_template'")->rowCount() > 0;
    if (!$table_exists) {
        $pdo->exec("
            CREATE TABLE IF NOT EXISTS `mkt_notify_template` (
              `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '模板ID',
              `template_name` varchar(100) NOT NULL COMMENT '模板名称',
              `template_type` tinyint(1) NOT NULL COMMENT '模板类型：1=短信，2=微信',
              `template_code` varchar(50) DEFAULT NULL COMMENT '模板编码',
              `title` varchar(100) DEFAULT NULL COMMENT '模板标题',
              `content` text NOT NULL COMMENT '模板内容',
              `params` varchar(255) DEFAULT NULL COMMENT '参数说明',
              `scenario` tinyint(1) NOT NULL COMMENT '应用场景：1=订单通知，2=生日祝福，3=促销提醒，4=其他',
              `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1=启用，0=禁用',
              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              PRIMARY KEY (`id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='通知模板表';
        ");

        // 添加初始模板数据
        $pdo->exec("
            INSERT INTO `mkt_notify_template` (`template_name`, `template_type`, `template_code`, `title`, `content`, `params`, `scenario`, `status`) VALUES 
            ('订单完成通知', 1, 'ORDER_COMPLETE', '订单完成通知', '尊敬的{customer_name}，您的订单{order_no}已完成，欢迎再次光临！', '{customer_name}:会员姓名,{order_no}:订单编号', 1, 1),
            ('会员生日祝福', 1, 'BIRTHDAY', '生日祝福', '亲爱的{customer_name}，祝您生日快乐！我们为您准备了生日特权，详情请查看会员中心。', '{customer_name}:会员姓名', 2, 1),
            ('促销活动提醒', 1, 'PROMOTION', '促销活动', '尊敬的{customer_name}，{activity_name}活动正在进行中，期待您的参与！', '{customer_name}:会员姓名,{activity_name}:活动名称', 3, 1),
            ('会员积分变动', 1, 'POINTS_CHANGE', '积分变动通知', '尊敬的{customer_name}，您的积分{change_type}{points}，当前积分余额{balance}。', '{customer_name}:会员姓名,{change_type}:变动类型,{points}:积分数量,{balance}:积分余额', 4, 1);
        ");
    }
} catch (PDOException $e) {
    $error = '初始化表失败：' . $e->getMessage();
}

// 处理通知发送/模板添加/编辑/删除
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加通知模板
    if ($_POST['action'] == 'add_template') {
        $template_name = isset($_POST['template_name']) ? trim($_POST['template_name']) : '';
        $template_type = isset($_POST['template_type']) ? intval($_POST['template_type']) : 1;
        $template_code = isset($_POST['template_code']) ? trim($_POST['template_code']) : '';
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $params = isset($_POST['params']) ? trim($_POST['params']) : '';
        $scenario = isset($_POST['scenario']) ? intval($_POST['scenario']) : 1;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($template_name) || empty($content)) {
            $error = '请填写完整模板信息！';
        } else {
            try {
                // 添加通知模板
                $stmt = $pdo->prepare("INSERT INTO mkt_notify_template (template_name, template_type, template_code, title, content, params, scenario, status, create_time) VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW())");
                $result = $stmt->execute([$template_name, $template_type, $template_code, $title, $content, $params, $scenario, $status]);

                if ($result) {
                    record_log("添加通知模板：{$template_name}");
                    $success = '通知模板添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: notify.php?view=templates&success=add');
                    exit;
                } else {
                    $error = '通知模板添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑通知模板
    elseif ($_POST['action'] == 'edit_template') {
        $template_id = isset($_POST['template_id']) ? intval($_POST['template_id']) : 0;
        $template_name = isset($_POST['template_name']) ? trim($_POST['template_name']) : '';
        $template_type = isset($_POST['template_type']) ? intval($_POST['template_type']) : 1;
        $template_code = isset($_POST['template_code']) ? trim($_POST['template_code']) : '';
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $params = isset($_POST['params']) ? trim($_POST['params']) : '';
        $scenario = isset($_POST['scenario']) ? intval($_POST['scenario']) : 1;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($template_id <= 0 || empty($template_name) || empty($content)) {
            $error = '请填写完整模板信息！';
        } else {
            try {
                // 更新通知模板
                $stmt = $pdo->prepare("UPDATE mkt_notify_template SET template_name = ?, template_type = ?, template_code = ?, title = ?, content = ?, params = ?, scenario = ?, status = ? WHERE id = ?");
                $result = $stmt->execute([$template_name, $template_type, $template_code, $title, $content, $params, $scenario, $status, $template_id]);

                if ($result) {
                    record_log("编辑通知模板：{$template_name}");
                    $success = '通知模板更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: notify.php?view=templates&success=edit');
                    exit;
                } else {
                    $error = '通知模板更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除通知模板
    elseif ($_POST['action'] == 'delete_template') {
        $template_id = isset($_POST['template_id']) ? intval($_POST['template_id']) : 0;

        if ($template_id <= 0) {
            $error = '无效的模板ID！';
        } else {
            try {
                // 获取模板名称，用于日志记录
                $stmt = $pdo->prepare("SELECT template_name FROM mkt_notify_template WHERE id = ?");
                $stmt->execute([$template_id]);
                $template = $stmt->fetch();

                if (!$template) {
                    $error = '模板不存在！';
                } else {
                    // 删除模板
                    $stmt = $pdo->prepare("DELETE FROM mkt_notify_template WHERE id = ?");
                    $result = $stmt->execute([$template_id]);

                    if ($result) {
                        record_log("删除通知模板：{$template['template_name']}");
                        $success = '通知模板删除成功！';
                    } else {
                        $error = '通知模板删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 创建通知任务
    elseif ($_POST['action'] == 'create_notify') {
        $notify_type = isset($_POST['notify_type']) ? intval($_POST['notify_type']) : 1;
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $send_type = isset($_POST['send_type']) ? intval($_POST['send_type']) : 1;
        $template_id = isset($_POST['template_id']) ? intval($_POST['template_id']) : 0;
        $member_ids = '';
        $condition_type = null;
        $condition_value = null;

        // 获取指定会员（单发）
        if ($send_type == 1 && isset($_POST['member_id'])) {
            $member_ids = json_encode([intval($_POST['member_id'])]);
        }
        // 获取指定会员（批量）
        elseif ($send_type == 2 && isset($_POST['member_ids'])) {
            $selected_members = [];
            foreach ($_POST['member_ids'] as $id) {
                $selected_members[] = intval($id);
            }
            $member_ids = json_encode($selected_members);
        }
        // 条件发送
        elseif ($send_type == 3) {
            $condition_type = isset($_POST['condition_type']) ? intval($_POST['condition_type']) : 1;
            $condition_value = isset($_POST['condition_value']) ? trim($_POST['condition_value']) : '';
        }

        if (empty($content) && $template_id <= 0) {
            $error = '请填写通知内容或选择模板！';
        } else {
            try {
                // 如果选择了模板，获取模板内容
                if ($template_id > 0) {
                    $stmt = $pdo->prepare("SELECT * FROM mkt_notify_template WHERE id = ?");
                    $stmt->execute([$template_id]);
                    $template = $stmt->fetch();

                    if ($template) {
                        $notify_type = $template['template_type'];
                        $title = $template['title'];
                        $content = $template['content'];
                    }
                }

                // 计算需要发送的会员数量
                $total_count = 0;

                if ($send_type == 1) {
                    $total_count = 1;
                } elseif ($send_type == 2 && !empty($member_ids)) {
                    $total_count = count(json_decode($member_ids, true));
                } elseif ($send_type == 3) {
                    // 根据条件计算会员数量
                    $where = ["status = 1"]; // 只考虑正常状态的会员
                    $params = [];

                    if ($condition_type == 1) { // 生日条件
                        $where[] = "DATE_FORMAT(birthday, '%m-%d') = DATE_FORMAT(?, '%m-%d')";
                        $params[] = $condition_value ?: date('Y-m-d');
                    } elseif ($condition_type == 2) { // 消费金额条件
                        $where[] = "total_amount >= ?";
                        $params[] = floatval($condition_value);
                    } elseif ($condition_type == 3) { // 会员等级条件
                        $where[] = "level = ?";
                        $params[] = intval($condition_value);
                    }

                    $where_clause = !empty($where) ? " WHERE " . implode(" AND ", $where) : "";
                    $sql = "SELECT COUNT(*) as count FROM mem_info $where_clause";

                    $stmt = $pdo->prepare($sql);
                    $stmt->execute($params);
                    $result = $stmt->fetch();
                    $total_count = $result['count'];
                }

                // 添加通知任务
                $stmt = $pdo->prepare("
                    INSERT INTO mkt_notify (
                        template_id, notify_type, title, content, 
                        send_type, member_ids, condition_type, condition_value, 
                        total_count, status, operator, create_time
                    ) VALUES (
                        ?, ?, ?, ?, 
                        ?, ?, ?, ?, 
                        ?, ?, ?, NOW()
                    )
                ");

                $operator = isset($_SESSION['username']) ? $_SESSION['username'] : '';
                $result = $stmt->execute([
                    $template_id,
                    $notify_type,
                    $title,
                    $content,
                    $send_type,
                    $member_ids,
                    $condition_type,
                    $condition_value,
                    $total_count,
                    1,
                    $operator
                ]);

                if ($result) {
                    $notify_id = $pdo->lastInsertId();
                    record_log("创建通知任务：ID={$notify_id}, 发送类型={$send_type}, 数量={$total_count}");

                    // 模拟发送通知（在实际应用中，这里应该是异步任务）
                    simulateSendNotify($pdo, $notify_id);

                    $success = '通知任务创建成功！';
                    // 重定向到没有参数的页面
                    header('Location: notify.php?success=send');
                    exit;
                } else {
                    $error = '通知任务创建失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 取消通知任务
    elseif ($_POST['action'] == 'cancel_notify') {
        $notify_id = isset($_POST['notify_id']) ? intval($_POST['notify_id']) : 0;

        if ($notify_id <= 0) {
            $error = '无效的通知ID！';
        } else {
            try {
                // 更新通知状态为已取消
                $stmt = $pdo->prepare("UPDATE mkt_notify SET status = 4 WHERE id = ? AND status = 1");
                $result = $stmt->execute([$notify_id]);

                if ($result && $stmt->rowCount() > 0) {
                    record_log("取消通知任务：ID={$notify_id}");
                    $success = '通知任务已取消！';
                } else {
                    $error = '通知任务取消失败，可能任务已开始处理！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 模拟发送通知的函数（实际应用中应该是异步处理）
function simulateSendNotify($pdo, $notify_id)
{
    try {
        // 获取通知任务信息
        $stmt = $pdo->prepare("SELECT * FROM mkt_notify WHERE id = ?");
        $stmt->execute([$notify_id]);
        $notify = $stmt->fetch();

        if (!$notify) return;

        // 更新为发送中状态
        $stmt = $pdo->prepare("UPDATE mkt_notify SET status = 2, send_time = NOW() WHERE id = ?");
        $stmt->execute([$notify_id]);

        $success_count = 0;
        $fail_count = 0;
        $member_list = [];

        // 根据发送类型获取会员列表
        if ($notify['send_type'] == 1 || $notify['send_type'] == 2) {
            // 单发或批量发送
            $member_ids = json_decode($notify['member_ids'], true) ?: [];
            if (!empty($member_ids)) {
                $placeholders = str_repeat('?,', count($member_ids) - 1) . '?';
                $sql = "SELECT id, name, phone FROM mem_info WHERE id IN ($placeholders) AND status = 1";
                $stmt = $pdo->prepare($sql);
                $stmt->execute($member_ids);
                $member_list = $stmt->fetchAll();
            }
        } else if ($notify['send_type'] == 3) {
            // 条件发送
            $where = ["status = 1"]; // 只考虑正常状态的会员
            $params = [];

            if ($notify['condition_type'] == 1) { // 生日条件
                $where[] = "DATE_FORMAT(birthday, '%m-%d') = DATE_FORMAT(?, '%m-%d')";
                $params[] = $notify['condition_value'] ?: date('Y-m-d');
            } elseif ($notify['condition_type'] == 2) { // 消费金额条件
                $where[] = "total_amount >= ?";
                $params[] = floatval($notify['condition_value']);
            } elseif ($notify['condition_type'] == 3) { // 会员等级条件
                $where[] = "level = ?";
                $params[] = intval($notify['condition_value']);
            }

            $where_clause = !empty($where) ? " WHERE " . implode(" AND ", $where) : "";
            $sql = "SELECT id, name, phone FROM mem_info $where_clause";

            $stmt = $pdo->prepare($sql);
            $stmt->execute($params);
            $member_list = $stmt->fetchAll();
        }

        // 模拟发送过程
        foreach ($member_list as $member) {
            // 在实际应用中，这里应该调用短信或微信API发送通知
            // 这里我们简单模拟一下成功率，假设90%的通知发送成功
            if (rand(1, 10) <= 9) {
                $success_count++;
            } else {
                $fail_count++;
            }
        }

        // 更新通知结果
        $stmt = $pdo->prepare("UPDATE mkt_notify SET status = 3, success_count = ?, fail_count = ? WHERE id = ?");
        $stmt->execute([$success_count, $fail_count, $notify_id]);
    } catch (PDOException $e) {
        // 记录错误日志
        record_log("发送通知异常：ID={$notify_id}, 错误=" . $e->getMessage());
    }
}

// 查看模板列表
if (isset($_GET['view']) && $_GET['view'] == 'templates') {
    $view_template_list = true;
    $view_notify_list = false;
    $view_send_notify = false;

    // 获取所有通知模板
    try {
        $stmt = $pdo->query("SELECT * FROM mkt_notify_template ORDER BY id DESC");
        $templates = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取通知模板失败：' . $e->getMessage();
        $templates = [];
    }

    // 判断是否显示编辑表单
    $show_form = false;
    $edit_template = null;

    if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
        $show_form = true;
        $edit_id = intval($_GET['id']);
        try {
            $stmt = $pdo->prepare("SELECT * FROM mkt_notify_template WHERE id = ?");
            $stmt->execute([$edit_id]);
            $edit_template = $stmt->fetch();
            if (!$edit_template) {
                $error = '模板不存在！';
                $show_form = false;
            }
        } catch (PDOException $e) {
            $error = '获取模板信息失败：' . $e->getMessage();
            $show_form = false;
        }
    }

    // 添加模板时显示表单
    if (isset($_GET['action']) && $_GET['action'] == 'add') {
        $show_form = true;
    }
}
// 发送通知
elseif (isset($_GET['view']) && $_GET['view'] == 'send') {
    $view_template_list = false;
    $view_notify_list = false;
    $view_send_notify = true;

    // 获取所有通知模板
    try {
        $stmt = $pdo->query("SELECT * FROM mkt_notify_template WHERE status = 1 ORDER BY id DESC");
        $templates = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取通知模板失败：' . $e->getMessage();
        $templates = [];
    }

    // 获取所有会员
    try {
        $stmt = $pdo->query("SELECT id, member_no, name, phone, level FROM mem_info WHERE status = 1 ORDER BY id DESC");
        $members = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取会员列表失败：' . $e->getMessage();
        $members = [];
    }
}
// 查看通知记录列表（默认）
else {
    $view_template_list = false;
    $view_notify_list = true;
    $view_send_notify = false;

    // 设置筛选条件
    $filter_notify_type = isset($_GET['notify_type']) ? intval($_GET['notify_type']) : 0;
    $filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;
    $filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
    $filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

    // 构建WHERE子句
    $where = [];
    $params = [];

    if ($filter_notify_type > 0) {
        $where[] = "notify_type = ?";
        $params[] = $filter_notify_type;
    }

    if ($filter_status > 0) {
        $where[] = "status = ?";
        $params[] = $filter_status;
    }

    if (!empty($filter_start_date)) {
        $where[] = "DATE(create_time) >= ?";
        $params[] = $filter_start_date;
    }

    if (!empty($filter_end_date)) {
        $where[] = "DATE(create_time) <= ?";
        $params[] = $filter_end_date;
    }

    $where_clause = !empty($where) ? " WHERE " . implode(" AND ", $where) : "";

    // 获取通知记录
    try {
        $sql = "
            SELECT * FROM mkt_notify
            $where_clause
            ORDER BY id DESC
            LIMIT 100
        ";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $notify_records = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取通知记录失败：' . $e->getMessage();
        $notify_records = [];
    }
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '通知模板添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '通知模板更新成功！';
    } elseif ($_GET['success'] == 'send') {
        $success = '通知任务创建成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员通知管理</h2>
            <div class="breadcrumb">
                <a href="index.php">会员营销</a> &gt; 通知管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="notify.php" class="btn <?php echo $view_notify_list ? 'btn-primary' : 'btn-secondary'; ?>">通知记录</a>
                <a href="notify.php?view=templates" class="btn <?php echo $view_template_list ? 'btn-primary' : 'btn-secondary'; ?>">通知模板</a>
                <a href="notify.php?view=send" class="btn <?php echo $view_send_notify ? 'btn-primary' : 'btn-secondary'; ?>">发送通知</a>
            </div>

            <?php if ($view_template_list): ?>
                <!-- 通知模板管理 -->
                <div class="action-bar">
                    <a href="notify.php?view=templates&action=add" class="btn btn-add">添加模板</a>
                </div>

                <?php if ($show_form): ?>
                    <div class="form-container">
                        <h3><?php echo $edit_template ? '编辑通知模板' : '添加通知模板'; ?></h3>
                        <form method="post" action="">
                            <input type="hidden" name="action" value="<?php echo $edit_template ? 'edit_template' : 'add_template'; ?>">
                            <?php if ($edit_template): ?>
                                <input type="hidden" name="template_id" value="<?php echo $edit_template['id']; ?>">
                            <?php endif; ?>

                            <div class="form-group">
                                <label for="template_name">模板名称：</label>
                                <input type="text" id="template_name" name="template_name" value="<?php echo $edit_template ? htmlspecialchars($edit_template['template_name']) : ''; ?>" required>
                            </div>

                            <div class="form-group">
                                <label for="template_type">模板类型：</label>
                                <select id="template_type" name="template_type">
                                    <option value="1" <?php echo ($edit_template && $edit_template['template_type'] == 1) ? 'selected' : ''; ?>>短信</option>
                                    <option value="2" <?php echo ($edit_template && $edit_template['template_type'] == 2) ? 'selected' : ''; ?>>微信</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="template_code">模板编码：</label>
                                <input type="text" id="template_code" name="template_code" value="<?php echo $edit_template ? htmlspecialchars($edit_template['template_code']) : ''; ?>">
                                <small>第三方平台模板编码（如有）</small>
                            </div>

                            <div class="form-group">
                                <label for="title">模板标题：</label>
                                <input type="text" id="title" name="title" value="<?php echo $edit_template ? htmlspecialchars($edit_template['title']) : ''; ?>">
                                <small>微信通知需要标题</small>
                            </div>

                            <div class="form-group">
                                <label for="content">模板内容：</label>
                                <textarea id="content" name="content" rows="5" required><?php echo $edit_template ? htmlspecialchars($edit_template['content']) : ''; ?></textarea>
                                <small>可使用变量如：{customer_name}、{order_no}等，在参数说明中说明</small>
                            </div>

                            <div class="form-group">
                                <label for="params">参数说明：</label>
                                <input type="text" id="params" name="params" value="<?php echo $edit_template ? htmlspecialchars($edit_template['params']) : ''; ?>">
                                <small>格式：{变量名}:说明,{变量名}:说明</small>
                            </div>

                            <div class="form-group">
                                <label for="scenario">应用场景：</label>
                                <select id="scenario" name="scenario">
                                    <option value="1" <?php echo ($edit_template && $edit_template['scenario'] == 1) ? 'selected' : ''; ?>>订单通知</option>
                                    <option value="2" <?php echo ($edit_template && $edit_template['scenario'] == 2) ? 'selected' : ''; ?>>生日祝福</option>
                                    <option value="3" <?php echo ($edit_template && $edit_template['scenario'] == 3) ? 'selected' : ''; ?>>促销提醒</option>
                                    <option value="4" <?php echo ($edit_template && $edit_template['scenario'] == 4) ? 'selected' : ''; ?>>其他</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="1" <?php echo ($edit_template && $edit_template['status'] == 1) ? 'selected' : ''; ?>>启用</option>
                                    <option value="0" <?php echo ($edit_template && $edit_template['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                                </select>
                            </div>

                            <div class="form-actions">
                                <button type="submit" class="btn btn-success">保存</button>
                                <a href="notify.php?view=templates" class="btn btn-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                <?php endif; ?>

                <div class="table-container">
                    <h3>通知模板列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>模板名称</th>
                                <th>模板类型</th>
                                <th>模板标题</th>
                                <th>应用场景</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($templates)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无通知模板</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($templates as $template): ?>
                                    <tr>
                                        <td><?php echo $template['id']; ?></td>
                                        <td><?php echo htmlspecialchars($template['template_name']); ?></td>
                                        <td>
                                            <?php
                                            if ($template['template_type'] == 1) echo '短信';
                                            elseif ($template['template_type'] == 2) echo '微信';
                                            ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($template['title'] ?: '-'); ?></td>
                                        <td>
                                            <?php
                                            if ($template['scenario'] == 1) echo '订单通知';
                                            elseif ($template['scenario'] == 2) echo '生日祝福';
                                            elseif ($template['scenario'] == 3) echo '促销提醒';
                                            elseif ($template['scenario'] == 4) echo '其他';
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($template['status'] == 1) echo '<span class="status-active">启用</span>';
                                            else echo '<span class="status-inactive">禁用</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($template['create_time'])); ?></td>
                                        <td>
                                            <a href="notify.php?view=templates&action=edit&id=<?php echo $template['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete_template">
                                                <input type="hidden" name="template_id" value="<?php echo $template['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-delete" onclick="return confirm('确定要删除这个模板吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php elseif ($view_send_notify): ?>
                <!-- 发送通知 -->
                <div class="form-container">
                    <h3>发送会员通知</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="create_notify">

                        <div class="form-group">
                            <label for="notify_type">通知类型：</label>
                            <select id="notify_type" name="notify_type">
                                <option value="1">短信</option>
                                <option value="2">微信</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="template_id">选择模板：</label>
                            <select id="template_id" name="template_id">
                                <option value="0">不使用模板</option>
                                <?php foreach ($templates as $template): ?>
                                    <option value="<?php echo $template['id']; ?>">
                                        <?php echo htmlspecialchars($template['template_name']); ?>
                                        (<?php echo $template['template_type'] == 1 ? '短信' : '微信'; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="title">通知标题：</label>
                            <input type="text" id="title" name="title">
                            <small>仅微信通知需要标题，使用模板时会替换为模板标题</small>
                        </div>

                        <div class="form-group">
                            <label for="content">通知内容：</label>
                            <textarea id="content" name="content" rows="5"></textarea>
                            <small>使用模板时会替换为模板内容</small>
                        </div>

                        <div class="form-group">
                            <label for="send_type">发送方式：</label>
                            <select id="send_type" name="send_type" onchange="showSendOptions(this.value)">
                                <option value="1">单个会员</option>
                                <option value="2">批量会员</option>
                                <option value="3">条件筛选</option>
                            </select>
                        </div>

                        <!-- 单个会员选项 -->
                        <div id="single_member" class="send-option">
                            <div class="form-group">
                                <label for="member_id">选择会员：</label>
                                <select id="member_id" name="member_id">
                                    <option value="">请选择会员</option>
                                    <?php foreach ($members as $member): ?>
                                        <option value="<?php echo $member['id']; ?>">
                                            <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?>
                                            (<?php echo htmlspecialchars($member['member_no']); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>

                        <!-- 批量会员选项 -->
                        <div id="batch_members" class="send-option" style="display:none;">
                            <div class="form-group">
                                <label>选择多个会员：</label>
                                <div style="max-height: 200px; overflow-y: auto; border: 1px solid #ccc; padding: 10px;">
                                    <?php foreach ($members as $member): ?>
                                        <div>
                                            <input type="checkbox" name="member_ids[]" value="<?php echo $member['id']; ?>" id="member_<?php echo $member['id']; ?>">
                                            <label for="member_<?php echo $member['id']; ?>">
                                                <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?>
                                                (<?php echo htmlspecialchars($member['member_no']); ?>)
                                            </label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        </div>

                        <!-- 条件筛选选项 -->
                        <div id="condition_filter" class="send-option" style="display:none;">
                            <div class="form-group">
                                <label for="condition_type">筛选条件：</label>
                                <select id="condition_type" name="condition_type">
                                    <option value="1">生日会员（今日或指定日期）</option>
                                    <option value="2">消费金额（大于等于指定金额）</option>
                                    <option value="3">会员等级</option>
                                </select>
                            </div>
                            <div class="form-group">
                                <label for="condition_value">条件值：</label>
                                <input type="text" id="condition_value" name="condition_value">
                                <small>生日条件格式：YYYY-MM-DD（留空表示今日）；消费金额：直接输入数字；会员等级：1=普通，2=银卡，3=金卡，4=黑卡</small>
                            </div>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">创建发送任务</button>
                            <button type="reset" class="btn btn-secondary">重置</button>
                        </div>
                    </form>
                </div>

                <script>
                    function showSendOptions(sendType) {
                        document.getElementById('single_member').style.display = 'none';
                        document.getElementById('batch_members').style.display = 'none';
                        document.getElementById('condition_filter').style.display = 'none';

                        if (sendType == '1') {
                            document.getElementById('single_member').style.display = 'block';
                        } else if (sendType == '2') {
                            document.getElementById('batch_members').style.display = 'block';
                        } else if (sendType == '3') {
                            document.getElementById('condition_filter').style.display = 'block';
                        }
                    }
                </script>
            <?php else: ?>
                <!-- 通知记录（默认视图） -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="notify_type">通知类型：</label>
                                <select id="notify_type" name="notify_type">
                                    <option value="0">全部</option>
                                    <option value="1" <?php echo ($filter_notify_type == 1) ? 'selected' : ''; ?>>短信</option>
                                    <option value="2" <?php echo ($filter_notify_type == 2) ? 'selected' : ''; ?>>微信</option>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="0">全部</option>
                                    <option value="1" <?php echo ($filter_status == 1) ? 'selected' : ''; ?>>待发送</option>
                                    <option value="2" <?php echo ($filter_status == 2) ? 'selected' : ''; ?>>发送中</option>
                                    <option value="3" <?php echo ($filter_status == 3) ? 'selected' : ''; ?>>已完成</option>
                                    <option value="4" <?php echo ($filter_status == 4) ? 'selected' : ''; ?>>已取消</option>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>

                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="notify.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <h3>通知记录列表（最近100条）</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>通知类型</th>
                                <th>标题</th>
                                <th>发送方式</th>
                                <th>总数</th>
                                <th>成功</th>
                                <th>失败</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>发送时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($notify_records)): ?>
                                <tr>
                                    <td colspan="11" class="text-center">暂无通知记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($notify_records as $record): ?>
                                    <tr>
                                        <td><?php echo $record['id']; ?></td>
                                        <td>
                                            <?php
                                            if ($record['notify_type'] == 1) echo '短信';
                                            elseif ($record['notify_type'] == 2) echo '微信';
                                            ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($record['title'] ?: '-'); ?></td>
                                        <td>
                                            <?php
                                            if ($record['send_type'] == 1) echo '单发';
                                            elseif ($record['send_type'] == 2) echo '批量';
                                            elseif ($record['send_type'] == 3) {
                                                if ($record['condition_type'] == 1) echo '生日筛选';
                                                elseif ($record['condition_type'] == 2) echo '消费金额筛选';
                                                elseif ($record['condition_type'] == 3) echo '会员等级筛选';
                                                else echo '条件筛选';
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo $record['total_count']; ?></td>
                                        <td><?php echo $record['success_count']; ?></td>
                                        <td><?php echo $record['fail_count']; ?></td>
                                        <td>
                                            <?php
                                            if ($record['status'] == 1) echo '<span class="status-pending">待发送</span>';
                                            elseif ($record['status'] == 2) echo '<span class="status-pending">发送中</span>';
                                            elseif ($record['status'] == 3) echo '<span class="status-active">已完成</span>';
                                            elseif ($record['status'] == 4) echo '<span class="status-inactive">已取消</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($record['create_time'])); ?></td>
                                        <td><?php echo $record['send_time'] ? date('Y-m-d H:i', strtotime($record['send_time'])) : '-'; ?></td>
                                        <td>
                                            <?php if ($record['status'] == 1): ?>
                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="cancel_notify">
                                                    <input type="hidden" name="notify_id" value="<?php echo $record['id']; ?>">
                                                    <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要取消这个通知任务吗？');">取消</button>
                                                </form>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>