<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('store');

// 记录访问日志
record_log('访问门店管理页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>门店管理</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>门店数量</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM store_info");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">营业中：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM store_info WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>员工总数</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM emp_info");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">在职员工：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM emp_info WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>今日排班</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM emp_work WHERE work_date = CURDATE()");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">出勤情况：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM emp_work WHERE work_date = CURDATE() AND status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>设备状态</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM equip_info");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">正常运行：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM equip_info WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="multi.php" class="function-link">
                    <h3>多门店管理</h3>
                </a>
                <a href="info.php" class="function-link">
                    <h3>门店信息管理</h3>
                </a>
                <a href="employee.php" class="function-link">
                    <h3>员工管理</h3>
                </a>
                <a href="equipment.php" class="function-link">
                    <h3>设备管理</h3>
                </a>
            </div>

            <h2>门店概览</h2>
            <div class="store-overview">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>门店名称</th>
                            <th>联系电话</th>
                            <th>营业时间</th>
                            <th>员工数量</th>
                            <th>设备数量</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT s.*, 
                                           (SELECT COUNT(*) FROM emp_info WHERE store_id = s.id) as emp_count,
                                           (SELECT COUNT(*) FROM equip_info WHERE store_id = s.id) as equip_count
                                    FROM store_info s
                                    ORDER BY s.id LIMIT 5");
                        while ($row = $stmt->fetch()) {
                            echo "<tr>
                                <td>{$row['store_name']}</td>
                                <td>{$row['contact_phone']}</td>
                                <td>{$row['business_hours']}</td>
                                <td>{$row['emp_count']}</td>
                                <td>{$row['equip_count']}</td>
                                <td>" . ($row['status'] == 1 ? '营业中' : '已关闭') . "</td>
                            </tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>最近设备维护记录</h2>
            <div class="recent-maintenance">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>设备名称</th>
                            <th>所属门店</th>
                            <th>维护日期</th>
                            <th>维护类型</th>
                            <th>维护人员</th>
                            <th>维护描述</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT m.*, e.name as equip_name, s.store_name 
                                    FROM equip_maintain m
                                    JOIN equip_info e ON m.equip_id = e.id
                                    JOIN store_info s ON m.store_id = s.id
                                    ORDER BY m.maintain_date DESC LIMIT 5");
                        while ($row = $stmt->fetch()) {
                            echo "<tr>
                                <td>{$row['equip_name']}</td>
                                <td>{$row['store_name']}</td>
                                <td>{$row['maintain_date']}</td>
                                <td>" . ($row['maintain_type'] == 1 ? '已完成维护' : '计划维护') . "</td>
                                <td>{$row['operator']}</td>
                                <td>{$row['description']}</td>
                            </tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>